@@ -5,23 +5,26 @@ from omspy.order import Order, CompoundOrder
 
 
 class StopOrder(CompoundOrder):
-    symbol:str
-    side:str
+    symbol: str
+    side: str
     trigger_price: float
-    price:float = 0.0
-    quantity:int = 1
-    disclosed_quantity:int = 0
-    order_type:Tuple= ('LIMIT', 'SL-M')
+    price: float = 0.0
+    quantity: int = 1
+    disclosed_quantity: int = 0
+    order_type: Tuple = ("LIMIT", "SL-M")
 
     def __init__(self, **data):
         super().__init__(**data)
-        side_map = {'buy':'sell','sell':'buy'}
-        base_order = Order(symbol=self.symbol,
-                side=self.side,quantity=self.quantity,
-                disclosed_quantity=self.disclosed_quantity,
-                order_type=self.order_type[0],
-                price=self.price,
-                trigger_price=self.trigger_price)
+        side_map = {"buy": "sell", "sell": "buy"}
+        base_order = Order(
+            symbol=self.symbol,
+            side=self.side,
+            quantity=self.quantity,
+            disclosed_quantity=self.disclosed_quantity,
+            order_type=self.order_type[0],
+            price=self.price,
+            trigger_price=self.trigger_price,
+        )
 
         cover_order = base_order.clone()
         cover_order.order_type = self.order_type[1]
@@ -29,6 +32,7 @@ class StopOrder(CompoundOrder):
         self.add(base_order)
         self.add(cover_order)
 
+
 class StopLimitOrder(CompoundOrder):
     def __init__(
         self,
